searchData={"items":[{"type":"module","title":"Machete","doc":"Machete provides ergonomic match operators to help make your ExUnit tests more literate\n\nThe easiest way to explain Machete is to show it in action:\n\n```elixir\ndefmodule ExampleTest do\n  use ExUnit.Case\n  use Machete\n\n  test \"example test\" do\n    response = %{\n      id: 1,\n      name: \"Moe Fonebone\",\n      is_admin: false,\n      created_at: DateTime.utc_now()\n    }\n\n    assert response ~> %{\n      id: integer(positive: true),\n      name: string(),\n      is_admin: false,\n      created_at: datetime(roughly: :now, time_zone: :utc)\n    }\n  end\nend\n```\n\nAt its heart, Machete provides the following two things:\n\n* A new `~>` operator (the 'squiggle arrow') that does flexible matching of\n  its left operator with its right operator\n* A set of parametric matchers such as `string()` or `integer()` which can match\n  against general types\n\nThese building blocks let you define test expectations that can match data against any\ncombination of literals, variables, or parametrically defined matchers\n\nWhen your matches fail, Machete provides useful error messages in ExUnit that point you directly\nat any failing matches using [jq syntax](https://stedolan.github.io/jq/manual/#Basicfilters)","ref":"Machete.html"},{"type":"module","title":"Matching literals & variables - Machete","doc":"Machete matches directly against literals & variables. The following examples will all match:\n\n```elixir\n# Builtin type literals all match themselves:\nassert 1 ~> 1\nassert \"abc\" ~> \"abc\"\n\n# Comparison is strict, using === semantics:\nrefute 1.0 ~> 1\nrefute \"123\" ~> 123\n\n# Variables 'just work' everywhere; no pinning required!\na_number = 1\nassert a_number ~> 1\nassert 1 ~> a_number\nassert a_number ~> a_number\n\n# Date-like types are compared using the relevant `compare/2` function:\nassert ~D[2021-02-01] ~> ~D[2021-02-01]\n\n# Regexes match using =~ semantics:\nassert \"abc\" ~> ~r/abc/\n\n# Structs can be matched on a subset of their fields:\nassert %User{name: \"Moe\"} ~> struct_like(User, name: string())\n```","ref":"Machete.html#module-matching-literals-variables"},{"type":"module","title":"Type-based matchers - Machete","doc":"Machete comes with parametric matchers defined for a variety of types. Many of these matchers\ntake optional arguments to further refine matches (for example, `integer(positive: true)` will\nmatch positive integers). For details, see the documentation of specific matchers below. The\nfollowing matchers are defined by Machete:\n\n* [`atom()`](`Machete.AtomMatcher.atom/1`) matches atoms\n* [`boolean()`](`Machete.BooleanMatcher.boolean/1`) matches boolean values\n* [`date()`](`Machete.DateMatcher.date/1`) matches `Date` instances\n* [`datetime()`](`Machete.DateTimeMatcher.datetime/1`) matches `DateTime` instances\n* [`falsy()`](`Machete.FalsyMatcher.falsy/1`) matches falsy values\n* [`float()`](`Machete.FloatMatcher.float/1`) matches float values\n* [`integer()`](`Machete.IntegerMatcher.integer/1`) matches integer values\n* [`iso8601_datetime()`](`Machete.ISO8601DateTimeMatcher.iso8601_datetime/1`) matches ISO8601 formatted strings\n* [`json()`](`Machete.JSONMatcher.json/1`) matches JSON formatted structures\n* [`is_a()`](`Machete.IsAMatcher.is_a/1`) matches against a struct type\n* [`naive_datetime()`](`Machete.NaiveDateTimeMatcher.naive_datetime/1`) matches `NaiveDateTime` instances\n* [`pid()`](`Machete.PIDMatcher.pid/1`) matches process IDs\n* [`port()`](`Machete.PortMatcher.port/1`) matches Erlang ports\n* [`reference()`](`Machete.ReferenceMatcher.reference/1`) matches Erlang references\n* [`string()`](`Machete.StringMatcher.string/1`) matches UTF-8 binaries\n* [`struct_like()`](`Machete.StructLikeMatcher.struct_like/2`) matches structs based on type and a set of fields\n* [`term()`](`Machete.TermMatcher.term/1`) matches any term (including nil)\n* [`time()`](`Machete.TimeMatcher.time/1`) matches `Time` instances\n* [`truthy()`](`Machete.TruthyMatcher.truthy/1`) matches truthy values\n* [`unix_time()`](`Machete.UnixTimeMatcher.unix_time/1`) matches integers that represent unix time","ref":"Machete.html#module-type-based-matchers"},{"type":"module","title":"Collection matchers - Machete","doc":"Collections can be matched as literals, with their contents being recursively matched. This\nusage requires knowing the exact shape of the collection up front, and may not always be\nsuitable. For cases where you may need more flexible collection matching, Machete provides the\nfollowing matchers:\n\n* [`in_any_order()`](`Machete.InAnyOrderMatcher.in_any_order/1`) matches lists in any order\n* [`indifferent_access()`](`Machete.IndifferentAccessMatcher.indifferent_access/1`) matches maps, considering similar atom and string keys to be\n  equivalent\n* [`list()`](`Machete.ListMatcher.list/1`) matches lists, with optional constraints on element type & list length\n* [`map()`](`Machete.MapMatcher.map/1`) matches maps, with optional constraints on key and value types & map size\n* [`subset()`](`Machete.SubsetMatcher.subset/1`) matches maps against its intersection with a (possibly larger) map\n* [`superset()`](`Machete.SupersetMatcher.superset/1`) matches maps against its intersection with a (possibly smaller) map","ref":"Machete.html#module-collection-matchers"},{"type":"module","title":"Miscellaneous matchers - Machete","doc":"* [`all()`](`Machete.AllMatcher.all/1`) matches the value against a set of matchers, requiring all of them to match\n* [`any()`](`Machete.AnyMatcher.any/1`) matches the value against a set of matchers, requiring at least one of them to match\n* [`maybe()`](`Machete.MaybeMatcher.maybe/1`) matches using a specified matcher, but also matches nil\n* [`none()`](`Machete.NoneMatcher.none/1`) matches the value against a set of matchers, requiring none of them to match","ref":"Machete.html#module-miscellaneous-matchers"},{"type":"module","title":"Write your own matchers - Machete","doc":"Implementing your own matchers is easy! Behind the scenes, parametric matchers are plain\nfunctions which return structs conforming to the `Machete.Matchable` protocol. You can implement\nyour own matchers by doing the same; a good place to start would be to look at something like\nthe [falsy matcher](`Machete.FalsyMatcher`) as a starting point.\n\nFor more adhoc matchers, you can also define a function which returns the output of an existing\nmatcher. For example, if you wanted to define a matcher named `tags()` which would match\na (possibly empty) list of non-empty strings without whitespace, you could do so like so:\n\n```elixir\ndef tags(), do: list(elements: string(empty: false, whitespace: false))\n\nassert %{\n  tags: [\"cool\", \"awesome\", \"not_lame\"]\n} ~> %{\n  tags: tags()\n}\n```\n\nThis allows you to easily DRY up your test expectations, keeping a centralized notion of what\nvarious formats in your data look like","ref":"Machete.html#module-write-your-own-matchers"},{"type":"macro","title":"Machete.__using__/1","doc":"Brings the `~>` and `~>>` operators into scope, along with `assert/1` and `refute/1` macros to\nbe aware of them. Also brings the set of parameteric matchers listed above into scope. Typical\nuse of this is to `use Machete` at the top of your ExUnit tests, taking care to place this after\nany `use ExUnit...` calls to ensure that the relevant `assert/1` and `refute/1` macros are\nproperly scoped","ref":"Machete.html#__using__/1"},{"type":"module","title":"Machete.Assertions","doc":"Macros for use within the context of ExUnit tests, to provide `~>` awareness to `assert/1` and\n`refute/1` macros. Because macros cannot be defined in multiple modules, proper use of this\nmodule requires the user to take `ExUnit.Assertions`' version of `assert/1` and `refute/1` out\nof scope, and to allow this module's versions of those macros to call through to\n`ExUnit.Assertions`' version for conditions other than `~>`. See `Machete.__using__/1` for\ndetails.","ref":"Machete.Assertions.html"},{"type":"macro","title":"Machete.Assertions.assert/1","doc":"A custom implementation of the `assert/1` macro to provide support for useful errors on `~>`\nmismatches; all other patterns are passed through to `ExUnit.Assertions.assert/1`","ref":"Machete.Assertions.html#assert/1"},{"type":"macro","title":"Machete.Assertions.refute/1","doc":"A custom implementation of the `refute/1` macro to provide support for useful errors on `~>`\nmismatches; all other patterns are passed through to `ExUnit.Assertions.refute/1`","ref":"Machete.Assertions.html#refute/1"},{"type":"protocol","title":"Machete.Matchable","doc":"Defines a protocol to determine how a given term may match against a type. The\n`Machete.Matchable` protocol is central to the Machete library, and conformance to it is\nnecessary for any type to be used on the right hand side of a `~>` match","ref":"Machete.Matchable.html"},{"type":"function","title":"Machete.Matchable.mismatches/2","doc":"Examines the value of the passed term and returns the way(s) in which it does not conform to the\nbase type instance's requirements, expressed as a list of `Machete.Mismatch` structs. If there\nare no such mismatches (that is, if the passed term 'matches' against the base type instance),\nimplementations of this protocol may return an empty list or `nil`; they are semantically\nequivalent and are both allowed for ease of implementation. Implementors of this protocol may be interested in the `Machete.Mismatch.mismatch/2`\nfunction to easily create mismatches\n\nNote that the argument order to this function is the opposite of that for the `~>` and `~>>`\noperators; conformance to this protocol is a property of the match, and not the term being\nmatched","ref":"Machete.Matchable.html#mismatches/2"},{"type":"type","title":"Machete.Matchable.t/0","doc":"All the types that implement this protocol.","ref":"Machete.Matchable.html#t:t/0"},{"type":"module","title":"Machete.Mismatch","doc":"Data and functions to deal with representing mismatches","ref":"Machete.Mismatch.html"},{"type":"function","title":"Machete.Mismatch.format_mismatches/2","doc":"Pretty prints the specified list of mismatches, in a manner suitable for presentation to the\nuser","ref":"Machete.Mismatch.html#format_mismatches/2"},{"type":"function","title":"Machete.Mismatch.mismatch/2","doc":"Constructs an instance of `Matchable.Mismatch` with the given message and path, wrapped in\na list and suitable for return from a `Machete.Matchable.mismatches/2` call","ref":"Machete.Mismatch.html#mismatch/2"},{"type":"function","title":"Machete.Mismatch.safe_inspect/1","doc":"Helper that inspects the given term ensuring map ordering","ref":"Machete.Mismatch.html#safe_inspect/1"},{"type":"type","title":"Machete.Mismatch.t/0","doc":"Describes the details of a mismatch","ref":"Machete.Mismatch.html#t:t/0"},{"type":"module","title":"Machete.Operators","doc":"Defines implementations for the `~>` and `~>>` operators","ref":"Machete.Operators.html"},{"type":"function","title":"Machete.Operators.~>/2","doc":"Matches data on the left hand side against matcher(s) on the right hand side. Matching is\ndetermined by calling the `Machete.Matchable.mismatches/2` protocol function using the right\nhand side's implementation\n\nExamples:\n\n    iex> 1 ~> 1\n    true\n\n    iex> 1 ~> integer()\n    true\n\n    iex> \"1\" ~> integer()\n    false\n\n    iex> %{a: 1, b: \"abc\"} ~> %{a: 1, b: string()}\n    true\n\nReturns a boolean result indicating whether the left hand side matched against the right hand\nside","ref":"Machete.Operators.html#~%3E/2"},{"type":"function","title":"Machete.Operators.~>>/2","doc":"Returns the list of mismatches between the left and right hand side arguments, determined by \ncalling the `Machete.Matchable.mismatches/2` protocol function using the right hand side's\nimplementation\n\nExamples:\n\n    iex> 1 ~>> 1\n    []\n\n    iex> 1 ~>> integer()\n    []\n\n    iex> \"1\" ~>> integer()\n    [%Machete.Mismatch{message: \"\\\"1\\\" is not an integer\", path: []}]\n\n    iex> %{a: 1} ~>> %{a: 2}\n    [%Machete.Mismatch{message: \"1 is not equal to 2\", path: [:a]}]\n\nReturns a (possibly empty) list of `Machete.Mismatch` structs","ref":"Machete.Operators.html#~%3E%3E/2"},{"type":"module","title":"Machete.AllMatcher","doc":"Defines a matcher that matches against a set of matchers, requiring all of them to match","ref":"Machete.AllMatcher.html"},{"type":"function","title":"Machete.AllMatcher.all/1","doc":"Matches against a set of matchers, requiring all of them to match\n\nTakes a list of matchers as its sole (mandatory) argument\n\nExamples:\n\n    iex> assert \"abc\" ~> all([term(), string()])\n    true\n\n    iex> refute :abc ~> all([term(), string()])\n    false","ref":"Machete.AllMatcher.html#all/1"},{"type":"opaque","title":"Machete.AllMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.AllMatcher.html#t:t/0"},{"type":"module","title":"Machete.AnyMatcher","doc":"Defines a matcher that matches against a set of matchers, requiring at least one of them to match","ref":"Machete.AnyMatcher.html"},{"type":"function","title":"Machete.AnyMatcher.any/1","doc":"Matches against a set of matchers, requiring at least one of them to match\n\nTakes a list of matchers as its sole (mandatory) argument\n\nExamples:\n\n    iex> assert \"abc\" ~> any([string(), integer()])\n    true\n\n    iex> refute :abc ~> any([string(), integer()])\n    false","ref":"Machete.AnyMatcher.html#any/1"},{"type":"opaque","title":"Machete.AnyMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.AnyMatcher.html#t:t/0"},{"type":"module","title":"Machete.AtomMatcher","doc":"Defines a matcher that matches atom values","ref":"Machete.AtomMatcher.html"},{"type":"function","title":"Machete.AtomMatcher.atom/1","doc":"Matches against atom values\n\nTakes no arguments\n\nExamples:\n    \n    iex> assert :a ~> atom()\n    true\n\n    iex> refute \"a\" ~> atom()\n    false","ref":"Machete.AtomMatcher.html#atom/1"},{"type":"type","title":"Machete.AtomMatcher.opts/0","doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.AtomMatcher.html#t:opts/0"},{"type":"opaque","title":"Machete.AtomMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.AtomMatcher.html#t:t/0"},{"type":"module","title":"Machete.BooleanMatcher","doc":"Defines a matcher that matches boolean values","ref":"Machete.BooleanMatcher.html"},{"type":"function","title":"Machete.BooleanMatcher.boolean/1","doc":"Matches against boolean values\n\nTakes no arguments\n\nExamples:\n\n    iex> assert true ~> boolean()\n    true\n\n    iex> assert true ~> boolean()\n    true\n\n    iex> refute 1 ~> boolean()\n    false\n\n    iex> refute nil ~> boolean()\n    false","ref":"Machete.BooleanMatcher.html#boolean/1"},{"type":"type","title":"Machete.BooleanMatcher.opts/0","doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.BooleanMatcher.html#t:opts/0"},{"type":"opaque","title":"Machete.BooleanMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.BooleanMatcher.html#t:t/0"},{"type":"module","title":"Machete.DateMatcher","doc":"Defines a matcher that matches Date values","ref":"Machete.DateMatcher.html"},{"type":"function","title":"Machete.DateMatcher.date/1","doc":"Matches against Date values\n\nTakes the following arguments:\n\n* `exactly`: Requires the matched Date to be exactly equal to the specified Date. The atom `:today` can\n  be used to use today as the specified Date\n* `roughly`: Requires the matched Date to be within +/- 1 day of the specified Date. The atom\n  `:today` can be used to use today as the specified Date\n* `before`: Requires the matched Date to be before or equal to the specified Date. The atom\n  `:today` can be used to use today as the specified Date\n* `after`: Requires the matched Date to be after or equal to the specified Date. The atom\n  `:today` can be used to use today as the specified Date\n\nExamples:\n\n    iex> assert Date.utc_today() ~> date()\n    true\n\n    iex> assert Date.utc_today() ~> date(exactly: :today)\n    true\n\n    iex> assert ~D[2020-01-01] ~> date(exactly: ~D[2020-01-01])\n    true\n\n    iex> assert Date.utc_today() ~> date(roughly: :today)\n    true\n\n    iex> assert ~D[2020-01-01] ~> date(roughly: ~D[2020-01-02])\n    true\n\n    iex> assert ~D[2020-01-01] ~> date(before: :today)\n    true\n\n    iex> assert ~D[2020-01-01] ~> date(before: ~D[3000-01-01])\n    true\n\n    iex> assert ~D[3000-01-01] ~> date(after: :today)\n    true\n\n    iex> assert ~D[3000-01-01] ~> date(after: ~D[2020-01-01])\n    true","ref":"Machete.DateMatcher.html#date/1"},{"type":"type","title":"Machete.DateMatcher.opts/0","doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.DateMatcher.html#t:opts/0"},{"type":"opaque","title":"Machete.DateMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.DateMatcher.html#t:t/0"},{"type":"module","title":"Machete.DateTimeMatcher","doc":"Defines a matcher that matches DateTime values","ref":"Machete.DateTimeMatcher.html"},{"type":"function","title":"Machete.DateTimeMatcher.datetime/1","doc":"Matches against DateTime values\n\nTakes the following arguments:\n\n* `precision`: Requires the matched DateTime to have the specified microsecond precision\n* `time_zone`: Requires the matched DateTime to have the specified time zone. The atom `:utc`\n  can be used to specify the \"Etc/UTC\" time zone\n* `exactly`: Requires the matched DateTime to be exactly equal to the specified DateTime\n* `roughly`: Requires the matched DateTime to be within +/- 10 seconds of the specified DateTime.\n  The atom `:now` can be used to use the current time as the specified DateTime\n* `before`: Requires the matched DateTime to be before or equal to the specified DateTime. The\n  atom `:now` can be used to use the current time as the specified DateTime\n* `after`: Requires the matched DateTime to be after or equal to the specified DateTime. The\n  atom `:now` can be used to use the current time as the specified DateTime\n\nExamples:\n\n    iex> assert DateTime.utc_now() ~> datetime()\n    true\n\n    iex> assert DateTime.utc_now() ~> datetime(precision: 6)\n    true\n\n    iex> assert DateTime.utc_now() ~> datetime(time_zone: :utc)\n    true\n\n    iex> assert DateTime.utc_now() ~> datetime(time_zone: \"Etc/UTC\")\n    true\n\n    iex> assert ~U[2020-01-01 00:00:00.000000Z] ~> datetime(exactly: ~U[2020-01-01 00:00:00.000000Z])\n    true\n\n    iex> assert DateTime.utc_now() ~> datetime(roughly: :now)\n    true\n\n    iex> assert ~U[2020-01-01 00:00:00.000000Z] ~> datetime(roughly: ~U[2020-01-01 00:00:05.000000Z])\n    true\n\n    iex> assert ~U[2020-01-01 00:00:00.000000Z] ~> datetime(before: :now)\n    true\n\n    iex> assert ~U[2020-01-01 00:00:00.000000Z] ~> datetime(before: ~U[3000-01-01 00:00:00.000000Z])\n    true\n\n    iex> assert ~U[3000-01-01 00:00:00.000000Z] ~> datetime(after: :now)\n    true\n\n    iex> assert ~U[3000-01-01 00:00:00.000000Z] ~> datetime(after: ~U[2020-01-01 00:00:00.000000Z])\n    true","ref":"Machete.DateTimeMatcher.html#datetime/1"},{"type":"type","title":"Machete.DateTimeMatcher.opts/0","doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.DateTimeMatcher.html#t:opts/0"},{"type":"opaque","title":"Machete.DateTimeMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.DateTimeMatcher.html#t:t/0"},{"type":"module","title":"Machete.FalsyMatcher","doc":"Defines a matcher that matches falsy values","ref":"Machete.FalsyMatcher.html"},{"type":"function","title":"Machete.FalsyMatcher.falsy/1","doc":"Matches against [falsy values](https://hexdocs.pm/elixir/1.12/Kernel.html#module-truthy-and-falsy-values)\n\nTakes no arguments\n\nExamples:\n\n    iex> assert false ~> falsy()\n    true\n\n    iex> assert nil ~> falsy()\n    true\n\n    iex> refute true ~> falsy()\n    false","ref":"Machete.FalsyMatcher.html#falsy/1"},{"type":"type","title":"Machete.FalsyMatcher.opts/0","doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.FalsyMatcher.html#t:opts/0"},{"type":"opaque","title":"Machete.FalsyMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.FalsyMatcher.html#t:t/0"},{"type":"module","title":"Machete.FloatMatcher","doc":"Defines a matcher that matches float values","ref":"Machete.FloatMatcher.html"},{"type":"function","title":"Machete.FloatMatcher.float/1","doc":"Matches against float values\n\nTakes the following arguments:\n\n* `positive`: When `true`, requires the matched float be positive or zero\n* `strictly_positive`: When `true`, requires the matched float be positive and nonzero\n* `negative`: When `true`, requires the matched float be negative or zero\n* `strictly_negative`: When `true`, requires the matched float be negative and nonzero\n* `nonzero`: When `true`, requires the matched float be nonzero\n* `min`: Requires the matched float be greater than or equal to the specified value\n* `max`: Requires the matched float be less than or equal to the specified value\n\nExamples:\n\n    iex> assert 1.0 ~> float()\n    true\n\n    iex> assert 1.0 ~> float(positive: true)\n    true\n\n    iex> assert 0.0 ~> float(positive: true)\n    true\n\n    iex> assert -1.0 ~> float(positive: false)\n    true\n\n    iex> refute 0.0 ~> float(positive: false)\n    false\n\n    iex> assert 1.0 ~> float(strictly_positive: true)\n    true\n\n    iex> refute 0.0 ~> float(strictly_positive: true)\n    false\n\n    iex> assert -1.0 ~> float(strictly_positive: false)\n    true\n\n    iex> assert 0.0 ~> float(strictly_positive: false)\n    true\n\n    iex> assert -1.0 ~> float(negative: true)\n    true\n\n    iex> assert 0.0 ~> float(negative: true)\n    true\n\n    iex> assert 1.0 ~> float(negative: false)\n    true\n\n    iex> refute 0.0 ~> float(negative: false)\n    false\n\n    iex> assert -1.0 ~> float(strictly_negative: true)\n    true\n\n    iex> refute 0.0 ~> float(strictly_negative: true)\n    false\n\n    iex> assert 1.0 ~> float(strictly_negative: false)\n    true\n\n    iex> assert 0.0 ~> float(strictly_negative: false)\n    true\n\n    iex> assert 1.0 ~> float(nonzero: true)\n    true\n\n    iex> assert 0.0 ~> float(nonzero: false)\n    true\n\n    iex> assert 2.0 ~> float(min: 2.0)\n    true\n\n    iex> assert 2.0 ~> float(max: 2.0)\n    true","ref":"Machete.FloatMatcher.html#float/1"},{"type":"type","title":"Machete.FloatMatcher.opts/0","doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.FloatMatcher.html#t:opts/0"},{"type":"opaque","title":"Machete.FloatMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.FloatMatcher.html#t:t/0"},{"type":"module","title":"Machete.ISO8601DateTimeMatcher","doc":"Defines a matcher that matches ISO8601 formatted strings","ref":"Machete.ISO8601DateTimeMatcher.html"},{"type":"function","title":"Machete.ISO8601DateTimeMatcher.iso8601_datetime/1","doc":"Matches against ISO8601 formatted strings\n\nTakes the following arguments:\n\n* `precision`: Requires the matched ISO8601 string to have the specified microsecond precision\n* `time_zone`: Requires the matched ISO8601 string to have the specified time zone. The atom\n  `:utc` can be used to specify the \"Etc/UTC\" time zone\n* `offset_required`: Requires the matched ISO8601 string to have a timezone. Defaults to true\n* `exactly`: Requires the matched ISO8601 string to be exactly equal to the specified DateTime\n* `roughly`: Requires the matched ISO8601 string to be within +/- 10 seconds of the specified\n  DateTime. This values must be specified as a DateTime. The atom `:now` can be used to use the\n  current time as the specified DateTime\n* `before`: Requires the matched ISO8601 string to be before or equal to the specified\n  DateTime. This values must be specified as a DateTime. The atom `:now` can be used to use the\n  current time as the specified DateTime\n* `after`: Requires the matched ISO8601 string to be after or equal to the specified DateTime.\n  This values must be specified as a DateTime. The atom `:now` can be used to use the current\n  time as the specified DateTime\n\nExamples:\n\n    iex> assert \"2020-01-01T00:00:00.000000Z\" ~> iso8601_datetime()\n    true\n\n    iex> assert \"2020-01-01T00:00:00.000000Z\" ~> iso8601_datetime(precision: 6)\n    true\n\n    iex> assert \"2020-01-01T00:00:00.000000Z\" ~> iso8601_datetime(time_zone: :utc)\n    true\n\n    iex> assert \"2020-01-01T00:00:00.000000Z\" ~> iso8601_datetime(time_zone: \"Etc/UTC\")\n    true\n\n    iex> assert \"2020-01-01 00:00:00.000000Z\" ~> iso8601_datetime(exactly: ~U[2020-01-01 00:00:00.000000Z])\n    true\n\n    iex> assert DateTime.utc_now() |> DateTime.to_iso8601() ~> iso8601_datetime(roughly: :now)\n    true\n\n    iex> assert NaiveDateTime.utc_now() |> NaiveDateTime.to_iso8601() ~> iso8601_datetime(roughly: :now, offset_required: false)\n    true\n\n    iex> assert \"2020-01-01T00:00:00.000000Z\" ~> iso8601_datetime(roughly: ~U[2020-01-01 00:00:05.000000Z])\n    true\n\n    iex> assert \"2020-01-01T00:00:00.000000Z\" ~> iso8601_datetime(before: :now)\n    true\n\n    iex> assert \"2020-01-01T00:00:00.000000Z\" ~> iso8601_datetime(before: ~U[3000-01-01 00:00:00.000000Z])\n    true\n\n    iex> assert \"3000-01-01T00:00:00.000000Z\" ~> iso8601_datetime(after: :now)\n    true\n\n    iex> assert \"3000-01-01T00:00:00.000000Z\" ~> iso8601_datetime(after: ~U[2020-01-01 00:00:00.000000Z])\n    true","ref":"Machete.ISO8601DateTimeMatcher.html#iso8601_datetime/1"},{"type":"type","title":"Machete.ISO8601DateTimeMatcher.opts/0","doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.ISO8601DateTimeMatcher.html#t:opts/0"},{"type":"opaque","title":"Machete.ISO8601DateTimeMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.ISO8601DateTimeMatcher.html#t:t/0"},{"type":"module","title":"Machete.InAnyOrderMatcher","doc":"Defines a matcher that matches lists in any order","ref":"Machete.InAnyOrderMatcher.html"},{"type":"function","title":"Machete.InAnyOrderMatcher.in_any_order/1","doc":"Matches lists in any order. Matchers are applied in all possible orders\nuntil one matches; *this can be exponentially expensive* for long lists.\n\nExamples:\n    iex> assert [1] ~> in_any_order([1])\n    true\n\n    iex> assert [2, 1] ~> in_any_order([1, 2])\n    true\n\n    iex> assert [1, \"a\", :a] ~> in_any_order([string(), atom(), integer()])\n    true\n\n    iex> refute [1, 2] ~> in_any_order([1, 3])\n    false","ref":"Machete.InAnyOrderMatcher.html#in_any_order/1"},{"type":"opaque","title":"Machete.InAnyOrderMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.InAnyOrderMatcher.html#t:t/0"},{"type":"module","title":"Machete.IndifferentAccessMatcher","doc":"Defines a matcher that matches indifferently (that is, it considers similar atom and string keys\nto be equivalent)","ref":"Machete.IndifferentAccessMatcher.html"},{"type":"function","title":"Machete.IndifferentAccessMatcher.indifferent_access/1","doc":"Defines a matcher that matches indifferently (that is, it considers similar atom and string keys\nto be equivalent)\n\nTakes a map as its sole (mandatory) argument\n\nExamples:\n\n    iex> assert %{a: 1} ~> indifferent_access(%{a: 1})\n    true\n\n    iex> assert %{\"a\" => 1} ~> indifferent_access(%{\"a\" => 1})\n    true\n\n    iex> assert %{a: 1} ~> indifferent_access(%{\"a\" => 1})\n    true\n\n    iex> assert %{\"a\" => 1} ~> indifferent_access(%{a: 1})\n    true\n\n    iex> assert %{1 => 1} ~> indifferent_access(%{1 => 1})\n    true","ref":"Machete.IndifferentAccessMatcher.html#indifferent_access/1"},{"type":"opaque","title":"Machete.IndifferentAccessMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.IndifferentAccessMatcher.html#t:t/0"},{"type":"module","title":"Machete.IntegerMatcher","doc":"Defines a matcher that matches integer values","ref":"Machete.IntegerMatcher.html"},{"type":"function","title":"Machete.IntegerMatcher.integer/1","doc":"Matches against integer values\n\nTakes the following arguments:\n\n* `positive`: When `true`, requires the matched integer be positive or zero\n* `strictly_positive`: When `true`, requires the matched integer be positive and nonzero\n* `negative`: When `true`, requires the matched integer be negative or zero\n* `strictly_negative`: When `true`, requires the matched integer be negative and nonzero\n* `nonzero`: When `true`, requires the matched integer be nonzero\n* `min`: Requires the matched integer be greater than or equal to the specified value\n* `max`: Requires the matched integer be less than or equal to the specified value\n\nExamples:\n\n    iex> assert 1 ~> integer()\n    true\n\n    iex> assert 1 ~> integer(positive: true)\n    true\n\n    iex> assert 0 ~> integer(positive: true)\n    true\n\n    iex> assert -1 ~> integer(positive: false)\n    true\n\n    iex> refute 0 ~> integer(positive: false)\n    false\n\n    iex> assert 1 ~> integer(strictly_positive: true)\n    true\n\n    iex> refute 0 ~> integer(strictly_positive: true)\n    false\n\n    iex> assert -1 ~> integer(strictly_positive: false)\n    true\n\n    iex> assert 0 ~> integer(strictly_positive: false)\n    true\n\n    iex> assert -1 ~> integer(negative: true)\n    true\n\n    iex> assert 0 ~> integer(negative: true)\n    true\n\n    iex> assert 1 ~> integer(negative: false)\n    true\n\n    iex> refute 0 ~> integer(negative: false)\n    false\n\n    iex> assert -1 ~> integer(strictly_negative: true)\n    true\n\n    iex> refute 0 ~> integer(strictly_negative: true)\n    false\n\n    iex> assert 1 ~> integer(strictly_negative: false)\n    true\n\n    iex> assert 0 ~> integer(strictly_negative: false)\n    true\n\n    iex> assert 1 ~> integer(nonzero: true)\n    true\n\n    iex> assert 0 ~> integer(nonzero: false)\n    true\n\n    iex> assert 2 ~> integer(min: 2)\n    true\n\n    iex> assert 2 ~> integer(max: 2)\n    true","ref":"Machete.IntegerMatcher.html#integer/1"},{"type":"type","title":"Machete.IntegerMatcher.opts/0","doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.IntegerMatcher.html#t:opts/0"},{"type":"opaque","title":"Machete.IntegerMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.IntegerMatcher.html#t:t/0"},{"type":"module","title":"Machete.IsAMatcher","doc":"Defines a matcher that matches againt a type of struct","ref":"Machete.IsAMatcher.html"},{"type":"function","title":"Machete.IsAMatcher.is_a/1","doc":"Matches against a type of struct. Similar to `Kernel.struct/2`, the argument may be a module name\nor a struct instance. In both cases, the match is concerned solely with type equivalence.\n\nExamples:\n\n    iex> assert %URI{} ~> is_a(URI)\n    true\n\n    iex> assert %URI{} ~> is_a(%URI{})\n    true\n\n    iex> refute %URI{} ~> is_a(DateTime)\n    false","ref":"Machete.IsAMatcher.html#is_a/1"},{"type":"opaque","title":"Machete.IsAMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.IsAMatcher.html#t:t/0"},{"type":"module","title":"Machete.JSONMatcher","doc":"Defines a matcher that matches JSON documents","ref":"Machete.JSONMatcher.html"},{"type":"function","title":"Machete.JSONMatcher.json/1","doc":"Matches against JSON documents whose deserialization matches a provided matcher\n\nTakes a matcher as its sole (mandatory) argument\n\nExamples:\n\n    iex> assert \"{}\" ~> json(map())\n    true\n\n    iex> assert ~s({\"a\": 1}) ~> json(%{\"a\" => 1})\n    true\n\n    iex> assert \"[]\" ~> json(list())\n    true\n\n    iex> assert \"[1,2,3]\" ~> json([1,2,3])\n    true\n\n    iex> assert ~s(\"abc\") ~> json(string())\n    true\n\n    iex> assert \"123\" ~> json(integer())\n    true\n\n    iex> assert \"true\" ~> json(boolean())\n    true\n\n    iex> assert \"null\" ~> json(nil)\n    true","ref":"Machete.JSONMatcher.html#json/1"},{"type":"opaque","title":"Machete.JSONMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.JSONMatcher.html#t:t/0"},{"type":"module","title":"Machete.ListMatcher","doc":"Defines a matcher that matches lists","ref":"Machete.ListMatcher.html"},{"type":"function","title":"Machete.ListMatcher.list/1","doc":"Matches lists. Useful for cases where you wish to match against the general shape / size of\na list, but cannot match against a literal list\n\nTakes the following arguments:\n\n* `elements`: A matcher to use against all elements in the list\n* `match_mode`: How to apply the `elements` matcher to the elements in the list. `:all`, `:any`,\n  and `:none` each match if all, any, or none of the list's elements match the `elements` matcher,\n  respectively. A non-negative integer requires at least `n` of the elements in the list to match.\n  Defaults to `:all`\n* `length`: Requires the matched list to be exactly the specified length\n* `min`: Requires the matched list to be greater than or equal to the specified length\n* `max`: Requires the matched list to be less than or equal to the specified length\n\nExamples:\n    iex> assert [1] ~> list(elements: integer())\n    true\n\n    iex> assert [1, \"a\", :b] ~> list(elements: integer(), match_mode: :any)\n    true\n\n    iex> assert [\"a\", \"b\", :c] ~> list(elements: integer(), match_mode: :none)\n    true\n\n    iex> assert [1, 2, 3] ~> list(elements: integer(), match_mode: 2)\n    true\n\n    iex> assert [1] ~> list(length: 1)\n    true\n\n    iex> assert [1] ~> list(min: 1)\n    true\n\n    iex> assert [1] ~> list(max: 2)\n    true","ref":"Machete.ListMatcher.html#list/1"},{"type":"type","title":"Machete.ListMatcher.opts/0","doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.ListMatcher.html#t:opts/0"},{"type":"opaque","title":"Machete.ListMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.ListMatcher.html#t:t/0"},{"type":"module","title":"Machete.MapMatcher","doc":"Defines a matcher that matches maps","ref":"Machete.MapMatcher.html"},{"type":"function","title":"Machete.MapMatcher.map/1","doc":"Matches maps. Useful for cases where you wish to match against the general shape / size of\na map, but cannot match against a literal map (or use the `Machete.Superset` / `Machete.Subset`\nmatchers)\n\nTakes the following arguments:\n\n* `keys`: A matcher to use against all keys in the map\n* `values`: A matcher to use against all values in the map\n* `size`: Requires the matched map to be exactly the specified size\n* `min`: Requires the matched map to be greater than or equal to the specified size\n* `max`: Requires the matched map to be less than or equal to the specified size\n\nExamples:\n\n    iex> assert %{a: 1} ~> map()\n    true\n\n    iex> assert %{a: 1} ~> map(keys: atom())\n    true\n\n    iex> assert %{a: 1} ~> map(values: integer())\n    true\n\n    iex> assert %{a: 1} ~> map(size: 1)\n    true\n\n    iex> assert %{a: 1} ~> map(min: 1)\n    true\n\n    iex> assert %{a: 1} ~> map(max: 2)\n    true","ref":"Machete.MapMatcher.html#map/1"},{"type":"type","title":"Machete.MapMatcher.opts/0","doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.MapMatcher.html#t:opts/0"},{"type":"opaque","title":"Machete.MapMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.MapMatcher.html#t:t/0"},{"type":"module","title":"Machete.MaybeMatcher","doc":"Defines a matcher that matches against another matcher & also matches nil","ref":"Machete.MaybeMatcher.html"},{"type":"function","title":"Machete.MaybeMatcher.maybe/1","doc":"Matches against another matcher & also matches nil\n\nTakes another matcher as its sole (mandatory) argument\n\nExamples:\n\n    iex> assert nil ~> maybe(string())\n    true\n\n    iex> assert \"abc\" ~> maybe(string())\n    true","ref":"Machete.MaybeMatcher.html#maybe/1"},{"type":"opaque","title":"Machete.MaybeMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.MaybeMatcher.html#t:t/0"},{"type":"module","title":"Machete.NaiveDateTimeMatcher","doc":"Defines a matcher that matches NaiveDateTime values","ref":"Machete.NaiveDateTimeMatcher.html"},{"type":"function","title":"Machete.NaiveDateTimeMatcher.naive_datetime/1","doc":"Matches against NaiveDateTime values\n\nTakes the following arguments:\n\n* `precision`: Requires the matched NaiveDateTime to have the specified microsecond precision\n* `exactly`: Requires the matched NaiveDateTime to be exactly equal to the specified NaiveDateTime\n* `roughly`: Requires the matched NaiveDateTime to be within +/- 10 seconds of the specified\n   NaiveDateTime. The atom `:now` can be used to use the current time as the specified\n   NaiveDateTime\n* `before`: Requires the matched NaiveDateTime to be before or equal to the specified\n  NaiveDateTime. The atom `:now` can be used to use the current time as the specified\n  NaiveDateTime\n* `after`: Requires the matched NaiveDateTime to be after or equal to the specified\n  NaiveDateTime. The atom `:now` can be used to use the current time as the specified\n  NaiveDateTime\n\nExamples:\n\n    iex> assert NaiveDateTime.utc_now() ~> naive_datetime()\n    true\n\n    iex> assert NaiveDateTime.utc_now() ~> naive_datetime(precision: 6)\n    true\n\n    iex> assert ~N[2020-01-01 00:00:00.000000] ~> naive_datetime(exactly: ~N[2020-01-01 00:00:00.000000])\n    true\n\n    iex> assert NaiveDateTime.utc_now() ~> naive_datetime(roughly: :now)\n    true\n\n    iex> assert ~N[2020-01-01 00:00:00.000000] ~> naive_datetime(roughly: ~N[2020-01-01 00:00:05.000000])\n    true\n\n    iex> assert ~N[2020-01-01 00:00:00.000000] ~> naive_datetime(before: :now)\n    true\n\n    iex> assert ~N[2020-01-01 00:00:00.000000] ~> naive_datetime(before: ~N[3000-01-01 00:00:00.000000])\n    true\n\n    iex> assert ~N[3000-01-01 00:00:00.000000] ~> naive_datetime(after: :now)\n    true\n\n    iex> assert ~N[3000-01-01 00:00:00.000000] ~> naive_datetime(after: ~N[2020-01-01 00:00:00.000000])\n    true","ref":"Machete.NaiveDateTimeMatcher.html#naive_datetime/1"},{"type":"type","title":"Machete.NaiveDateTimeMatcher.opts/0","doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.NaiveDateTimeMatcher.html#t:opts/0"},{"type":"opaque","title":"Machete.NaiveDateTimeMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.NaiveDateTimeMatcher.html#t:t/0"},{"type":"module","title":"Machete.NoneMatcher","doc":"Defines a matcher that matches against a set of matchers, requiring none of them to match","ref":"Machete.NoneMatcher.html"},{"type":"function","title":"Machete.NoneMatcher.none/1","doc":"Matches against a set of matchers, requiring none of them to match\n\nTakes a list of matchers as its sole (mandatory) argument\n\nExamples:\n\n    iex> assert \"abc\" ~> none([integer(), float()])\n    true\n\n    iex> refute :abc ~> all([atom(), string()])\n    false","ref":"Machete.NoneMatcher.html#none/1"},{"type":"opaque","title":"Machete.NoneMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.NoneMatcher.html#t:t/0"},{"type":"module","title":"Machete.PIDMatcher","doc":"Defines a matcher that matches PID values","ref":"Machete.PIDMatcher.html"},{"type":"function","title":"Machete.PIDMatcher.pid/1","doc":"Matches against PID values\n\nTakes no arguments\n\nExamples:\n\n    iex> assert self() ~> pid()\n    true\n\n    iex> refute \"a\" ~> pid()\n    false","ref":"Machete.PIDMatcher.html#pid/1"},{"type":"type","title":"Machete.PIDMatcher.opts/0","doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.PIDMatcher.html#t:opts/0"},{"type":"opaque","title":"Machete.PIDMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.PIDMatcher.html#t:t/0"},{"type":"module","title":"Machete.PortMatcher","doc":"Defines a matcher that matches port values","ref":"Machete.PortMatcher.html"},{"type":"function","title":"Machete.PortMatcher.port/1","doc":"Matches against port values\n\nTakes no arguments\n\nExamples:\n\n    iex> assert hd(Port.list()) ~> port()\n    true\n\n    iex> refute \"a\" ~> port()\n    false","ref":"Machete.PortMatcher.html#port/1"},{"type":"type","title":"Machete.PortMatcher.opts/0","doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.PortMatcher.html#t:opts/0"},{"type":"opaque","title":"Machete.PortMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.PortMatcher.html#t:t/0"},{"type":"module","title":"Machete.ReferenceMatcher","doc":"Defines a matcher that matches reference values","ref":"Machete.ReferenceMatcher.html"},{"type":"function","title":"Machete.ReferenceMatcher.reference/1","doc":"Matches against reference values\n\nTakes no arguments\n\nExamples:\n\n    iex> assert make_ref() ~> reference()\n    true\n\n    iex> refute \"a\" ~> reference()\n    false","ref":"Machete.ReferenceMatcher.html#reference/1"},{"type":"type","title":"Machete.ReferenceMatcher.opts/0","doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.ReferenceMatcher.html#t:opts/0"},{"type":"opaque","title":"Machete.ReferenceMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.ReferenceMatcher.html#t:t/0"},{"type":"module","title":"Machete.StringMatcher","doc":"Defines a matcher that matches string values","ref":"Machete.StringMatcher.html"},{"type":"function","title":"Machete.StringMatcher.string/1","doc":"Matches against string values\n\nTakes the following arguments:\n\n* `empty`: When `true`, requires the matched string be empty. When false, requires the matched\n  string to be non-empty\n* `length`: Requires the matched string to be exactly the specified length\n* `min`: Requires the matched string to be greater than or equal to the specified length\n* `max`: Requires the matched string to be less than or equal to the specified length\n* `matches`: Requires the matched string to match the specified regex\n* `alphabetic`: When `true`, requires the matched string to consist of only alphabetic characters\n* `lowercase`: When `true`, requires the matched string to consist of only lowercase characters\n* `uppercase`: When `true`, requires the matched string to consist of only uppercase characters\n* `alphanumeric`: When `true`, requires the matched string to consist of only alphanumeric characters\n* `numeric`: When `true`, requires the matched string to consist of only numeric characters\n* `hexadecimal`: When `true`, requires the matched string to consist of only hexadecimal characters\n* `whitespace`: When `true`, requires the string to contain whitespace (possibly in addition to\n  other characters). When `false`, requires the matched string to not contain any whitespace\n* `starts_with`: Requires the matched string to start with the given prefix\n* `ends_with`: Requires the matched string to end with the given suffix\n\nExamples:\n\n    iex> assert \"\" ~> string()\n    true\n\n    iex> assert \"abc\" ~> string(length: 3)\n    true\n\n    iex> assert \"abc\" ~> string(min: 3)\n    true\n\n    iex> assert \"abc\" ~> string(max: 3)\n    true\n\n    iex> assert \"\" ~> string(empty: true)\n    true\n\n    iex> assert \"abc\" ~> string(empty: false)\n    true\n\n    iex> assert \"abc\" ~> string(matches: ~r/abc/)\n    true\n\n    iex> assert \"abc\" ~> string(alphabetic: true)\n    true\n\n    iex> assert \"123\" ~> string(alphabetic: false)\n    true\n\n    iex> assert \"abc\" ~> string(lowercase: true)\n    true\n\n    iex> assert \"ABC\" ~> string(lowercase: false)\n    true\n\n    iex> assert \"ABC\" ~> string(uppercase: true)\n    true\n\n    iex> assert \"abc\" ~> string(uppercase: false)\n    true\n\n    iex> assert \"abc123\" ~> string(alphanumeric: true)\n    true\n\n    iex> assert \"$\" ~> string(alphanumeric: false)\n    true\n\n    iex> assert \"123\" ~> string(numeric: true)\n    true\n\n    iex> assert \"abc\" ~> string(numeric: false)\n    true\n\n    iex> assert \"deadbeef0123\" ~> string(hexadecimal: true)\n    true\n\n    iex> assert \"ghi\" ~> string(hexadecimal: false)\n    true\n\n    iex> assert \"abc def\" ~> string(whitespace: true)\n    true\n\n    iex> assert \"abcdef\" ~> string(whitespace: false)\n    true\n\n    iex> assert \"abc\" ~> string(starts_with: \"ab\")\n    true\n\n    iex> assert \"abc\" ~> string(ends_with: \"bc\")\n    true","ref":"Machete.StringMatcher.html#string/1"},{"type":"type","title":"Machete.StringMatcher.opts/0","doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.StringMatcher.html#t:opts/0"},{"type":"opaque","title":"Machete.StringMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.StringMatcher.html#t:t/0"},{"type":"module","title":"Machete.StructLikeMatcher","doc":"Defines a matcher that matches structs only on a specified list of fields","ref":"Machete.StructLikeMatcher.html"},{"type":"function","title":"Machete.StructLikeMatcher.struct_like/2","doc":"Matches structs only on a specified list of fields\n\nStructs can be tricky to match because they have default values for fields which are not\nspecified at the point of creation. After creation these default values are otherwise\nindistinguishable from user-specified ones, and often get in the way of effective matching. This\nmatcher provides a convenient way around this by allowing the user to describe both the type of\nstruct expected as well as a set of matchers for fields within the struct; only the fields\nexplicitly listed in the matcher are examined.\n\nFields can be specified via a map or keyword list in a manner identical to that of\n`Kernel.struct/2`. Fields may be matched using any matcher, not just literal values.\n\nExamples:\n    iex> assert %URI{host: \"example.com\", path: \"/abc\"} ~> struct_like(URI, %{host: \"example.com\"})\n    true\n\n    iex> assert %URI{host: \"example.com\", path: \"/abc\"} ~> struct_like(URI, host: \"example.com\")\n    true\n\n    iex> assert %URI{host: \"example.com\", path: \"/abc\"} ~> struct_like(URI, host: string())\n    true\n\n    iex> refute %URI{host: \"example.com\"} ~> struct_like(URI, host: \"example.com\", path: \"/abc\")\n    false","ref":"Machete.StructLikeMatcher.html#struct_like/2"},{"type":"opaque","title":"Machete.StructLikeMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.StructLikeMatcher.html#t:t/0"},{"type":"module","title":"Machete.SubsetMatcher","doc":"Defines a matcher that matches maps which are a subset of a specified map","ref":"Machete.SubsetMatcher.html"},{"type":"function","title":"Machete.SubsetMatcher.subset/1","doc":"Matches maps which are a subset of a specified map\n\nTakes a map as its sole (mandatory) argument\n\nExamples:\n    iex> assert %{a: 1} ~> subset(%{a: 1})\n    true\n\n    iex> assert %{a: 1} ~> subset(%{a: 1, b: 1})\n    true","ref":"Machete.SubsetMatcher.html#subset/1"},{"type":"opaque","title":"Machete.SubsetMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.SubsetMatcher.html#t:t/0"},{"type":"module","title":"Machete.SupersetMatcher","doc":"Defines a matcher that matches maps which are a superset of a specified map","ref":"Machete.SupersetMatcher.html"},{"type":"function","title":"Machete.SupersetMatcher.superset/1","doc":"Matches maps which are a superset of a specified map\n\nTakes a map as its sole (mandatory) argument\n\nExamples:\n    iex> assert %{a: 1} ~> superset(%{a: 1})\n    true\n\n    iex> assert %{a: 1, b: 1} ~> superset(%{a: 1})\n    true","ref":"Machete.SupersetMatcher.html#superset/1"},{"type":"opaque","title":"Machete.SupersetMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.SupersetMatcher.html#t:t/0"},{"type":"module","title":"Machete.TermMatcher","doc":"Defines a matcher that matches everything","ref":"Machete.TermMatcher.html"},{"type":"function","title":"Machete.TermMatcher.term/1","doc":"Matches everything\n\nTakes no arguments\n\nExamples:\n\n    iex> assert \"a\" ~> term()\n    true\n\n    iex> assert :a ~> term()\n    true\n\n    iex> assert 1 ~> term()\n    true\n\n    iex> assert %{} ~> term()\n    true\n\n    iex> assert nil ~> term()\n    true","ref":"Machete.TermMatcher.html#term/1"},{"type":"type","title":"Machete.TermMatcher.opts/0","doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.TermMatcher.html#t:opts/0"},{"type":"opaque","title":"Machete.TermMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.TermMatcher.html#t:t/0"},{"type":"module","title":"Machete.TimeMatcher","doc":"Defines a matcher that matches Time values","ref":"Machete.TimeMatcher.html"},{"type":"function","title":"Machete.TimeMatcher.time/1","doc":"Matches against Time values\n\nTakes the following arguments:\n\n* `precision`: Requires the matched Time to have the specified microsecond precision\n* `exactly`: Requires the matched Time to be exactly equal to the specified Time\n* `roughly`: Requires the matched Time to be within +/- 10 seconds of the specified Time. The\n  atom `:now` can be used to use the current time as the specified Time\n* `before`: Requires the matched Time to be before or equal to the specified Time. The atom\n  `:now` can be used to use the current time as the specified Time\n* `after`: Requires the matched Time to be after or equal to the specified Time. The atom `:now`\n  can be used to use the current time as the specified Time\n\nExamples:\n\n    iex> assert Time.utc_now() ~> time()\n    true\n\n    iex> assert Time.utc_now() ~> time(precision: 6)\n    true\n\n    iex> assert ~T[00:00:00.000000] ~> time(exactly: ~T[00:00:00.000000])\n    true\n\n    iex> assert Time.utc_now() ~> time(roughly: :now)\n    true\n\n    iex> assert ~T[00:00:00.000000] ~> time(roughly: ~T[00:00:05.000000])\n    true\n\n    iex> assert ~T[00:00:00.000000] ~> time(before: :now)\n    true\n\n    iex> assert ~T[00:00:00.000000] ~> time(before: ~T[00:00:01.000000])\n    true\n\n    iex> assert ~T[23:59:59.999999] ~> time(after: :now)\n    true\n\n    iex> assert ~T[00:00:01.000000] ~> time(after: ~T[00:00:00.000000])\n    true","ref":"Machete.TimeMatcher.html#time/1"},{"type":"type","title":"Machete.TimeMatcher.opts/0","doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.TimeMatcher.html#t:opts/0"},{"type":"opaque","title":"Machete.TimeMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.TimeMatcher.html#t:t/0"},{"type":"module","title":"Machete.TruthyMatcher","doc":"Defines a matcher that matches truthy values","ref":"Machete.TruthyMatcher.html"},{"type":"function","title":"Machete.TruthyMatcher.truthy/1","doc":"Matches against [truthy values](https://hexdocs.pm/elixir/1.12/Kernel.html#module-truthy-and-falsy-values).\n\nTakes no arguments\n\nExamples:\n    \n    iex> assert true ~> truthy()\n    true\n\n    iex> assert 123 ~> truthy()\n    true\n\n    iex> refute false ~> truthy()\n    false\n\n    iex> refute nil ~> truthy()\n    false","ref":"Machete.TruthyMatcher.html#truthy/1"},{"type":"type","title":"Machete.TruthyMatcher.opts/0","doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.TruthyMatcher.html#t:opts/0"},{"type":"opaque","title":"Machete.TruthyMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.TruthyMatcher.html#t:t/0"},{"type":"module","title":"Machete.UnixTimeMatcher","doc":"Defines a matcher that matches integers that represent Unix time in milliseconds","ref":"Machete.UnixTimeMatcher.html"},{"type":"function","title":"Machete.UnixTimeMatcher.unix_time/1","doc":"Matches against integers that represent Unix time values in milliseconds\n\nTakes the following arguments:\n\n* `exactly`: Requires the matched Unix time to be exactly equal to the specified Unix time\n* `roughly`: Requires the matched Unix time to be within +/- 10 seconds of the specified Unix time. The\n  atom `:now` can be used to use the current time as the specified Unix time\n* `before`: Requires the matched Unix time to be before or equal to the specified Unix time. The atom\n  `:now` can be used to use the current time as the specified Unix time\n* `after`: Requires the matched Unix time to be after or equal to the specified Unix time. The atom `:now`\n  can be used to use the current time as the specified Unix time\n\nExamples:\n\n    iex> assert :os.system_time(:millisecond) ~> unix_time()\n    true\n\n    iex> assert 1681060000000 ~> unix_time(exactly: 1681060000000)\n    true\n\n    iex> assert :os.system_time(:millisecond) ~> unix_time(roughly: :now)\n    true\n\n    iex> assert 1681060000000 ~> unix_time(roughly: 1681060005000)\n    true\n\n    iex> assert 1681060000000 ~> unix_time(before: :now)\n    true\n\n    iex> assert 1681060000000 ~> unix_time(before: 1681090000000)\n    true\n\n    iex> assert 9991090000000 ~> unix_time(after: :now)\n    true\n\n    iex> assert 1681060000000 ~> unix_time(after: 0)\n    true","ref":"Machete.UnixTimeMatcher.html#unix_time/1"},{"type":"type","title":"Machete.UnixTimeMatcher.opts/0","doc":"Describes the arguments that can be passed to this matcher","ref":"Machete.UnixTimeMatcher.html#t:opts/0"},{"type":"opaque","title":"Machete.UnixTimeMatcher.t/0","doc":"Describes an instance of this matcher","ref":"Machete.UnixTimeMatcher.html#t:t/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}